@@ -27,7 +27,7 @@ def upload_static_file(path):
 
 def upload_file(path):
     dh = DriverHelper()
-    x = dh.upload_file_auto("studio-result", [path])
+    x = dh.upload_file_auto("studio-loop-link", [path])
     return x[0].split(";;")[-1]
 def remove(path):
     try:
