@@ -65,7 +65,7 @@ def create_lyric_outro(deezer_artist_id, lyric_outro_repeat,  arr_comp, outro_cl
         path_video = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-comp-outro-lyric-vid-audio.mp4")
         tmp_path_composite_outro = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-comp-outro-lyric-vid.mp4")
         tmp_clip = CompositeVideoClip(arr_comp).subclip(0, time_o)
-        tmp_clip.write_videofile(tmp_path_composite_outro, bitrate='500k', fps=24, codec='libx264', audio=False)
+        tmp_clip.write_videofile(tmp_path_composite_outro, bitrate='4M', fps=24, codec='libx264', audio=False)
         tmp_clip.close()
         audio_compilation = AudioFileClip(outro_sound)
         final_clip_path = create_loop(tmp_path_composite_outro, audio_compilation.duration)
@@ -179,7 +179,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
                     rs.close()
                     vidPathTmp = FFmpeg.add_null_sound(comp.video_path)
                     rs = VideoFileClip(vidPathTmp)
-                rs.write_videofile(introPath, bitrate='500k', fps=24, codec='libx264', audio=False)
+                rs.write_videofile(introPath, bitrate='4M', fps=24, codec='libx264', audio=False)
                 is_cont = True
                 rs.close()
             if comp.is_outro:
@@ -189,7 +189,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
                     rs.close()
                     vidPathTmp = FFmpeg.add_null_sound(comp.video_path)
                     rs = VideoFileClip(vidPathTmp)
-                rs.write_videofile(outroPath, bitrate='500k', fps=24, codec='libx264', audio=False)
+                rs.write_videofile(outroPath, bitrate='4M', fps=24, codec='libx264', audio=False)
                 is_cont = True
                 rs.close()
             if is_cont:
@@ -231,7 +231,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
         if max_duration <= 0:
             max_duration = max_real_duration
         final_clip = CompositeVideoClip(arr_composite).subclip(0, max_duration)
-        final_clip.write_videofile(path_video, bitrate='500k', fps=24, codec='libx264', logger=logger)
+        final_clip.write_videofile(path_video, bitrate='4M', fps=24, codec='libx264', logger=logger)
         final_clip.close()
     else:
         # make Compilation
@@ -245,20 +245,20 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
         if intro_time_real > 0:
             tmp_path_composite_intro = os.path.join(get_dir('coolbg_ffmpeg'),str(uuid.uuid4()) + "-comp-intro-vid.mp4")
             tmp_clip = CompositeVideoClip(arr_composite).subclip(0, intro_time_real)
-            tmp_clip.write_videofile(tmp_path_composite_intro, bitrate='500k', fps=24, codec='libx264', audio=False, logger=logger)
+            tmp_clip.write_videofile(tmp_path_composite_intro, bitrate='4M', fps=24, codec='libx264', audio=False, logger=logger)
             # tmp_clip.close()
 
         tmp_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-final-vid.mp4")
         tmp_path_maked_loop = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-final-vid.mp4")
         final_clip = CompositeVideoClip(arr_composite_no_intro).subclip(0, max_real_duration)
-        final_clip.write_videofile(tmp_path, bitrate='500k', fps=24, codec='libx264', audio=False, logger=logger)
+        final_clip.write_videofile(tmp_path, bitrate='4M', fps=24, codec='libx264', audio=False, logger=logger)
         #crop big video
         # x_center=final_clip.w/2
         # w_new=math.ceil(final_clip.h*final_clip.h/final_clip.w)
         # y1=0
         # h_new=final_clip.h
         # final_clip= crop.crop(final_clip, x_center=x_center, y1=y1, width=w_new, height=h_new)
-        # final_clip.write_videofile(tmp_path, bitrate='500k', fps=24, codec='libx264', audio=False)
+        # final_clip.write_videofile(tmp_path, bitrate='4M', fps=24, codec='libx264', audio=False)
         final_clip.close()
         if cnt_effect_vid > 1:
             final_clip = VideoFileClip(tmp_path, audio=False)
@@ -266,7 +266,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
             if cross > 3:
                 cross = 3
             clip = make_loopable.make_loopable(final_clip, cross)
-            clip.write_videofile(tmp_path_maked_loop, bitrate='500k', fps=24, codec='libx264', audio=False, logger=logger)
+            clip.write_videofile(tmp_path_maked_loop, bitrate='4M', fps=24, codec='libx264', audio=False, logger=logger)
             clip.close()
             final_clip.close()
             utils.remove(tmp_path)
@@ -577,6 +577,7 @@ class VideoComp(Component):
         self.kind = "video"
         self.is_intro=False
         self.is_outro=False
+        self.video_path = None
         self.c_type='video' #type get clip
         if "c_type" in json_data:
             self.c_type = json_data['c_type']
@@ -587,6 +588,7 @@ class VideoComp(Component):
         if self.is_canva:
             self.kind = "canva"
     def get_clip(self):
+
         if self.c_type == 'image':
             self.isLoop = False
             self.isSmoothLoop = False
@@ -600,6 +602,8 @@ class VideoComp(Component):
                     except:
                         is_loop_mk = True
                         pass
+                    if not self.video_path:
+                        is_loop_mk = True
                 else:
                     is_loop_mk = True
                 if is_loop_mk:
